@@ -33,6 +33,7 @@ class Account(object):
     def __init__(self, json_data):
         self.name = from_json(json_data, "name")
         self.email = from_json(json_data, "email")
+        self.username = from_json(json_data, "username")
 
     def __repr__(self):
         return u"<Account %s%s>" % (self.name,
@@ -64,8 +65,9 @@ class Change(object):
         self.subject = from_json(json_data, "subject")
         self.url = from_json(json_data, "url")
         self.owner = Account.from_json(json_data, "owner")
-        if 'sortKey' in json_data:
-            self.sortkey = from_json(json_data, "sortKey")
+        self.sortkey = from_json(json_data, "sortKey")
+        self.status = from_json(json_data, "status")
+        self.current_patchset = CurrentPatchset.from_json(json_data)
 
     def __repr__(self):
         return u"<Change %s, %s, %s>" % (self.number, self.project, self.branch)
@@ -97,6 +99,35 @@ class Patchset(object):
         return None
 
 
+class CurrentPatchset(Patchset):
+
+    """ Gerrit current patch set. """
+
+    def __init__(self, json_data):
+        super(CurrentPatchset, self).__init__(json_data)
+        self.author = Account.from_json(json_data, "author")
+        self.approvals = []
+        if "approvals" in json_data:
+            for approval in json_data["approvals"]:
+                self.approvals.append(Approval(approval))
+
+    def __repr__(self):
+        return u"<CurrentPatchset %s, %s>" % (self.number, self.revision)
+
+    @staticmethod
+    def from_json(json_data):
+        r""" Create a CurrentPatchset instance.
+
+        Return an instance of CurrentPatchset initialised with values from
+        "currentPatchSet" in `json_data`, or None if `json_data` does not
+        contain "currentPatchSet".
+
+        """
+        if "currentPatchSet" in json_data:
+            return CurrentPatchset(json_data["currentPatchSet"])
+        return None
+
+
 class Approval(object):
 
     """ Gerrit approval (verified, code review, etc). """
@@ -105,6 +136,7 @@ class Approval(object):
         self.category = from_json(json_data, "type")
         self.value = from_json(json_data, "value")
         self.description = from_json(json_data, "description")
+        self.approver = Account.from_json(json_data, "by")
 
     def __repr__(self):
         return u"<Approval %s %s>" % (self.description, self.value)
